@@ -94,6 +94,8 @@ from bigframes.operations.geo_ops import (
     geo_area_op,
     geo_st_astext_op,
     geo_st_boundary_op,
+    geo_st_centroid_op,
+    geo_st_convexhull_op,
     geo_st_difference_op,
     geo_st_geogfromtext_op,
     geo_st_geogpoint_op,
@@ -101,6 +103,7 @@ from bigframes.operations.geo_ops import (
     geo_st_isclosed_op,
     geo_x_op,
     geo_y_op,
+    GeoStBufferOp,
     GeoStDistanceOp,
     GeoStLengthOp,
 )
@@ -386,12 +389,15 @@ __all__ = [
     # Geo ops
     "geo_area_op",
     "geo_st_boundary_op",
+    "geo_st_centroid_op",
+    "geo_st_convexhull_op",
     "geo_st_difference_op",
     "geo_st_astext_op",
     "geo_st_geogfromtext_op",
     "geo_st_geogpoint_op",
     "geo_st_intersection_op",
     "geo_st_isclosed_op",
+    "GeoStBufferOp",
     "GeoStLengthOp",
     "geo_x_op",
     "geo_y_op",
