@@ -15,17 +15,15 @@ import pathlib
 
 import benchmark.utils as utils
 
-import bigframes.session
+import bigframes.pandas
 
 PAGE_SIZE = utils.READ_GBQ_COLAB_PAGE_SIZE
 
 
-def sort_output(
-    *, project_id, dataset_id, table_id, session: bigframes.session.Session
-):
+def sort_output(*, project_id, dataset_id, table_id):
     # TODO(tswast): Support alternative query if table_id is a local DataFrame,
     # e.g. "{local_inline}" or "{local_large}"
-    df = session._read_gbq_colab(
+    df = bigframes.pandas._read_gbq_colab(
         f"SELECT * FROM `{project_id}`.{dataset_id}.{table_id}"
     )
 
@@ -44,7 +42,7 @@ def sort_output(
 
 
 if __name__ == "__main__":
-    config = utils.get_configuration(include_table_id=True)
+    config = utils.get_configuration(include_table_id=True, start_session=False)
     current_path = pathlib.Path(__file__).absolute()
 
     utils.get_execution_time(
@@ -54,5 +52,4 @@ if __name__ == "__main__":
         project_id=config.project_id,
         dataset_id=config.dataset_id,
         table_id=config.table_id,
-        session=config.session,
     )
