@@ -139,6 +139,13 @@ def test_expm1(scalar_types_df: bpd.DataFrame, snapshot):
     snapshot.assert_match(sql, "out.sql")
 
 
+def test_floor_dt(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["timestamp_col"]]
+    sql = _apply_unary_op(bf_df, ops.FloorDtOp("DAY"), "timestamp_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
 def test_floor(scalar_types_df: bpd.DataFrame, snapshot):
     bf_df = scalar_types_df[["float64_col"]]
     sql = _apply_unary_op(bf_df, ops.floor_op, "float64_col")
@@ -160,6 +167,34 @@ def test_geo_st_astext(scalar_types_df: bpd.DataFrame, snapshot):
     snapshot.assert_match(sql, "out.sql")
 
 
+def test_geo_st_boundary(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["geography_col"]]
+    sql = _apply_unary_op(bf_df, ops.geo_st_boundary_op, "geography_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_geo_st_geogfromtext(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["string_col"]]
+    sql = _apply_unary_op(bf_df, ops.geo_st_geogfromtext_op, "string_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_geo_st_isclosed(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["geography_col"]]
+    sql = _apply_unary_op(bf_df, ops.geo_st_isclosed_op, "geography_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_geo_st_length(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["geography_col"]]
+    sql = _apply_unary_op(bf_df, ops.GeoStLengthOp(True), "geography_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
 def test_geo_x(scalar_types_df: bpd.DataFrame, snapshot):
     bf_df = scalar_types_df[["geography_col"]]
     sql = _apply_unary_op(bf_df, ops.geo_x_op, "geography_col")
@@ -237,6 +272,13 @@ def test_invert(scalar_types_df: bpd.DataFrame, snapshot):
     snapshot.assert_match(sql, "out.sql")
 
 
+def test_is_in(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["int64_col"]]
+    sql = _apply_unary_op(bf_df, ops.IsInOp(values=(1, 2, 3)), "int64_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
 def test_isalnum(scalar_types_df: bpd.DataFrame, snapshot):
     bf_df = scalar_types_df[["string_col"]]
     sql = _apply_unary_op(bf_df, ops.isalnum_op, "string_col")
@@ -363,6 +405,18 @@ def test_normalize(scalar_types_df: bpd.DataFrame, snapshot):
     snapshot.assert_match(sql, "out.sql")
 
 
+def test_obj_fetch_metadata(scalar_types_df: bpd.DataFrame, snapshot):
+    blob_s = scalar_types_df["string_col"].str.to_blob()
+    sql = blob_s.blob.version().to_frame().sql
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_obj_get_access_url(scalar_types_df: bpd.DataFrame, snapshot):
+    blob_s = scalar_types_df["string_col"].str.to_blob()
+    sql = blob_s.blob.read_url().to_frame().sql
+    snapshot.assert_match(sql, "out.sql")
+
+
 def test_pos(scalar_types_df: bpd.DataFrame, snapshot):
     bf_df = scalar_types_df[["float64_col"]]
     sql = _apply_unary_op(bf_df, ops.pos_op, "float64_col")
@@ -419,6 +473,25 @@ def test_str_slice(scalar_types_df: bpd.DataFrame, snapshot):
     snapshot.assert_match(sql, "out.sql")
 
 
+def test_strftime(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["timestamp_col"]]
+    sql = _apply_unary_op(bf_df, ops.StrftimeOp("%Y-%m-%d"), "timestamp_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_struct_field(nested_structs_types_df: bpd.DataFrame, snapshot):
+    bf_df = nested_structs_types_df[["people"]]
+
+    # When a name string is provided.
+    sql = _apply_unary_op(bf_df, ops.StructFieldOp("name"), "people")
+    snapshot.assert_match(sql, "out.sql")
+
+    # When an index integer is provided.
+    sql = _apply_unary_op(bf_df, ops.StructFieldOp(0), "people")
+    snapshot.assert_match(sql, "out.sql")
+
+
 def test_str_contains(scalar_types_df: bpd.DataFrame, snapshot):
     bf_df = scalar_types_df[["string_col"]]
     sql = _apply_unary_op(bf_df, ops.StrContainsOp("e"), "string_col")
@@ -510,6 +583,50 @@ def test_time(scalar_types_df: bpd.DataFrame, snapshot):
     snapshot.assert_match(sql, "out.sql")
 
 
+def test_to_datetime(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["int64_col"]]
+    sql = _apply_unary_op(bf_df, ops.ToDatetimeOp(), "int64_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_to_timestamp(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["int64_col"]]
+    sql = _apply_unary_op(bf_df, ops.ToTimestampOp(), "int64_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_to_timedelta(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["int64_col"]]
+    bf_df["duration_us"] = bpd.to_timedelta(bf_df["int64_col"], "us")
+    bf_df["duration_s"] = bpd.to_timedelta(bf_df["int64_col"], "s")
+    bf_df["duration_w"] = bpd.to_timedelta(bf_df["int64_col"], "W")
+
+    snapshot.assert_match(bf_df.sql, "out.sql")
+
+
+def test_unix_micros(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["timestamp_col"]]
+    sql = _apply_unary_op(bf_df, ops.UnixMicros(), "timestamp_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_unix_millis(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["timestamp_col"]]
+    sql = _apply_unary_op(bf_df, ops.UnixMillis(), "timestamp_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
+def test_unix_seconds(scalar_types_df: bpd.DataFrame, snapshot):
+    bf_df = scalar_types_df[["timestamp_col"]]
+    sql = _apply_unary_op(bf_df, ops.UnixSeconds(), "timestamp_col")
+
+    snapshot.assert_match(sql, "out.sql")
+
+
 def test_timedelta_floor(scalar_types_df: bpd.DataFrame, snapshot):
     bf_df = scalar_types_df[["int64_col"]]
     sql = _apply_unary_op(bf_df, ops.timedelta_floor_op, "int64_col")
